@@ -1,3 +1,6 @@
+# Copyright (c) Jupyter Development Team.
+# Distributed under the terms of the Modified BSD License.
+
 """
 Localization utilities to find available language packs and packages with
 localization data.
@@ -11,15 +14,15 @@ import re
 import sys
 import traceback
 from functools import lru_cache
-from typing import Dict, Pattern, Tuple
+from typing import Any, Dict, Optional, Pattern, Tuple
 
 import babel
 from packaging.version import parse as parse_version
 
 # See compatibility note on `group` keyword in https://docs.python.org/3/library/importlib.metadata.html#entry-points
-if sys.version_info < (3, 10):
+if sys.version_info < (3, 10):  # pragma: no cover
     from importlib_metadata import entry_points
-else:
+else:  # pragma: no cover
     from importlib.metadata import entry_points
 
 # Entry points
@@ -94,7 +97,7 @@ def _get_installed_language_pack_locales():
     for entry_point in entry_points(group=JUPYTERLAB_LANGUAGEPACK_ENTRY):
         try:
             data[entry_point.name] = os.path.dirname(entry_point.load().__file__)
-        except Exception:
+        except Exception:  # pragma: no cover
             messages.append(traceback.format_exc())
 
     message = "\n".join(messages)
@@ -139,7 +142,6 @@ def _main():
     if len(sys.argv) == 2:
         func_name = sys.argv[-1]
         func = globals().get(func_name, None)
-
         if func:
             try:
                 data, message = func()
@@ -182,8 +184,10 @@ def is_valid_locale(locale: str) -> bool:
         babel.Locale.parse(locale)
         valid = True
     except babel.core.UnknownLocaleError:
+        # no-op
         pass
     except ValueError:
+        # no-op
         pass
 
     return valid
@@ -211,7 +215,7 @@ def get_display_name(locale: str, display_locale: str = DEFAULT_LOCALE) -> str:
     display_name = loc.get_display_name(display_locale)
     if display_name:
         display_name = display_name[0].upper() + display_name[1:]
-    return display_name
+    return display_name  # type:ignore
 
 
 def merge_locale_data(language_pack_locale_data, package_locale_data):
@@ -410,12 +414,13 @@ class TranslationBundle:
     """
 
     def __init__(self, domain: str, locale: str):
+        """Initialize the bundle."""
         self._domain = domain
         self._locale = locale
 
         self.update_locale(locale)
 
-    def update_locale(self, locale: str):
+    def update_locale(self, locale: str) -> None:
         """
         Update the locale environment variables.
 
@@ -431,8 +436,10 @@ class TranslationBundle:
             language_pack_module = f"jupyterlab_language_pack_{locale}"
             try:
                 mod = importlib.import_module(language_pack_module)
+                assert mod.__file__ is not None  # noqa
                 localedir = os.path.join(os.path.dirname(mod.__file__), LOCALE_DIR)
             except Exception:
+                # no-op
                 pass
 
         gettext.bindtextdomain(self._domain, localedir=localedir)
@@ -605,16 +612,16 @@ class TranslationBundle:
         return self.npgettext(msgctxt, msgid, msgid_plural, n)
 
 
-class translator:
+class translator:  # noqa
     """
     Translations manager.
     """
 
-    _TRANSLATORS = {}
+    _TRANSLATORS: dict = {}
     _LOCALE = DEFAULT_LOCALE
 
     @staticmethod
-    def _update_env(locale: str):
+    def _update_env(locale: str) -> None:
         """
         Update the locale environment variables based on the settings.
 
@@ -643,7 +650,7 @@ class translator:
         return domain.replace("-", "_")
 
     @classmethod
-    def set_locale(cls, locale: str):
+    def set_locale(cls, locale: str) -> None:
         """
         Set locale for the translation bundles based on the settings.
 
@@ -686,14 +693,14 @@ class translator:
             trans = TranslationBundle(norm_domain, cls._LOCALE)
             cls._TRANSLATORS[norm_domain] = trans
 
-        return trans
+        return trans  # type:ignore
 
     @staticmethod
     def _translate_schema_strings(
-        translations,
+        translations: Any,
         schema: dict,
         prefix: str = "",
-        to_translate: Dict[Pattern, str] = None,
+        to_translate: Optional[Dict[Pattern, str]] = None,
     ) -> None:
         """Translate a schema in-place."""
         if to_translate is None:
